Enum diem_parallel_executor::task::ExecutionStatus[][src]

pub enum ExecutionStatus<T, E> {
    Success(T),
    Abort(E),
    SkipRest(T),
}
The execution result of a transaction

Variants

Success(T)

Transaction was executed successfully.

Tuple Fields of Success

0: T
Abort(E)

Transaction hit a none recoverable error during execution, halt the execution and propagate the error back to the caller.

Tuple Fields of Abort

0: E
SkipRest(T)

Transaction was executed successfully, but will skip the execution of the trailing transactions in the list

Tuple Fields of SkipRest

0: T