Trait diem_parallel_executor::task::Transaction[][src]

pub trait Transaction: Sync + Send + 'static {
    type Key: PartialOrd + Send + Sync + Clone + Hash + Eq;
    type Value: Send + Sync;
}
Trait that defines a transaction that could be parallel executed by the scheduler. Each transaction will write to a key value storage as their side effect.

Associated Types

Implementors