Enum diem_parallel_executor::task::ExecutionStatus [−][src]
pub enum ExecutionStatus<T, E> {
Success(T),
Abort(E),
SkipRest(T),
}Expand description
The execution result of a transaction
Variants
Transaction was executed successfully.
Transaction hit a none recoverable error during execution, halt the execution and propagate the error back to the caller.
Transaction was executed successfully, but will skip the execution of the trailing transactions in the list